import React, { useContext } from 'react';
import { Context as GraphContext } from './GraphContext.jsx';
import { addGraph } from './actions.js';
import { getGraph } from './api.js';

export default function Controls() {
  const {
    dispatch,
    state: { graph, currentNode, hoveredNode }
  } = useContext(GraphContext);

  const onClick = evt => {
    evt.preventDefault();

    if (graph.nodes.length > 1) return;

    // load data async then dispatch event
    getGraph().then(data => dispatch(addGraph(data)));
  };
  return (
    <div className="Controls">
      <button
        onClick={onClick}
        disabled={graph.nodes.length === 1 ? '' : 'disabled'}
      >
        Load graph
      </button>
      <table>
        <tbody>
          <tr>
            <td>Clicked:</td>
            <td>
              <code>{currentNode === null ? 'none' : currentNode}</code>
            </td>
          </tr>
          <tr>
            <td>Hovered:</td>
            <td>
              <code>{hoveredNode === null ? 'none' : hoveredNode}</code>
            </td>
          </tr>
        </tbody>
      </table>
    </div>
  );
}
