import React, { createContext, useReducer } from 'react';
import { ADD_GRAPH, SELECT_NODE, HOVER_NODE } from './const';

const defaultState = {
  graph: { nodes: [{ id: 0 }], edges: [] },
  currentNode: null,
  hoveredNode: null
};

const reducer = (state, action) => {
  switch (action.type) {
    case ADD_GRAPH:
      return {
        ...state,
        graph: {
          nodes: [...state.graph.nodes, ...action.payload.nodes],
          edges: [...state.graph.edges, ...action.payload.edges]
        }
      };

    case SELECT_NODE:
      return {
        ...state,
        currentNode: action.payload
      };

    case HOVER_NODE:
      return {
        ...state,
        hoveredNode: action.payload
      };

    default:
      return state;
  }
};

export const Context = createContext({});

export const Provider = ({ children }) => {
  const [state, dispatch] = useReducer(reducer, defaultState);

  return (
    <Context.Provider value={{ state, dispatch }}>{children}</Context.Provider>
  );
};
